@@ -91,7 +91,7 @@ read_copynumber <- function(input,
                             use_all = add_loh,
                             min_segnum = 0L,
                             max_copynumber = 20L,
-                            genome_build = c("hg19", "hg38", "mm10", "mm9"),
+                            genome_build = c("hg19", "hg38", "T2T", "mm10", "mm9", "ce11"),
                             genome_measure = c("called", "wg"),
                             complement = FALSE,
                             ...) {
